---
name: Bug report
about: Create a report to help us improve

---

## Description of your problem

**Please provide a minimal, self-contained, and reproducible example.**
```python
# [Your code here]
```

**Please provide the full traceback.**
```python
# [The error output here]
```

**Please provide any additional information below.**


## Versions and main components

* PyScaffold Version:
* Python Version:
* Operating system:
* How did you install PyScaffold: (conda/pip)
